@@ -3,6 +3,10 @@
 ##
 ## subset associations using constraints on interest measures 
 ## or items.
+##
+## Note: parent.frame(2) is used so eval uses variables from the 
+##       calling function (fix by ceboo)
+##
 
 ##****************************************************************
 ## subset for itemMatrix
@@ -10,7 +14,8 @@
 setMethod("subset", signature(x = "itemMatrix"),
     function(x, subset, ...) {
         if (missing(subset)) return(x)
-        i <- eval(substitute(subset), list(items=x))
+        i <- eval(substitute(subset), list(items=x),
+            parent.frame(2))
         x[i,]
     })
 
@@ -23,16 +28,20 @@ setMethod("subset", signature(x = "itemsets"),
     function(x, subset, ...) {
         if (missing(subset)) return(x)
         i <- eval(substitute(subset), c(quality(x),
-                list(items=items(x))))
+                list(items=items(x))),
+            parent.frame(2))
         x[i,]
     })
 
 setMethod("subset", signature(x = "rules"),
     function(x, subset, ...) {
         if (missing(subset)) return(x)
+        
         i <- eval(substitute(subset), c(quality(x),
-                list(lhs=lhs(x), rhs=rhs(x), items=items(x))))
+                list(lhs=lhs(x), rhs=rhs(x), items=items(x))),
+            parent.frame(2))
         x[i,]
     })
 
 
+
